VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "CClipFormats"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Attribute VB_Description = "Collection object that offers information about formats present on the system Clipboard."
' *************************************************************
'  Copyright 1999, Karl E. Peterson
'  http://www.mvps.org/vb/
' *************************************************************
'  Author grants royalty-free rights to use this code within
'  compiled applications. Selling or otherwise distributing
'  this source code is not allowed without author's express
'  permission.
' *************************************************************
Option Explicit

' Local variables
Private m_Fmts As Collection

' ************************************************
'  Initialization and Termination
' ************************************************
Private Sub Class_Initialize()
   Me.Refresh
End Sub

Private Sub Class_Terminate()
   Set m_Fmts = Nothing
End Sub

' ************************************************
'  Properties
' ************************************************
Public Property Get Item(ByVal nFmt As Long) As CClipFormat
Attribute Item.VB_Description = "Returns a CClipFormat object from the collection of available Clipboard formats."
Attribute Item.VB_UserMemId = 0
   ' Guard against request for non-existant format.
   On Error Resume Next
   Set Item = m_Fmts.Item(CStr(nFmt))
End Property

Public Property Get Count() As Long
Attribute Count.VB_Description = "Returns a value indicating the number of formats available on the Clipboard."
   Count = m_Fmts.Count
End Property

' ************************************************
'  Public Methods
' ************************************************
Public Property Get NewEnum() As IUnknown
Attribute NewEnum.VB_UserMemId = -4
Attribute NewEnum.VB_MemberFlags = "40"
   ' This property allows you to enumerate
   ' this collection with the For...Each syntax
   Set NewEnum = m_Fmts.[_NewEnum]
End Property

Public Function Present(ByVal nFmt As Long) As Boolean
Attribute Present.VB_Description = "Returns a value indicating whether an item on the Clipboard object matches a specified format."
   ' Test for availability of requested format.
   ' Could map directly to the standard object,
   ' but here's the API equivalent.
   If OpenClipboard(0&) Then
      Present = CBool(IsClipboardFormatAvailable(nFmt))
      Call CloseClipboard
   End If
End Function

Public Function GetName(ByVal nFmt As Long) As String
Attribute GetName.VB_Description = "Returns the textual description of any numeric Clipboard format."
   Dim nRet
   Dim sFmt As String

   ' Translate numeric constant into textual description.
   Select Case nFmt
      Case CF_TEXT
         sFmt = "Text (TXT)"
      Case CF_BITMAP
         sFmt = "Bitmap (BMP)"
      Case CF_METAFILEPICT
         sFmt = "Metafile (WMF)"
      Case CF_SYLK
         sFmt = "Microsoft Symbolic Link (SYLK)"
      Case CF_DIF
         sFmt = "Data Interchange Format (DIF)"
      Case CF_TIFF
         sFmt = "Tagged Interchange File Format (TIF)"
      Case CF_OEMTEXT
         sFmt = "OEM Text"
      Case CF_DIB
         sFmt = "Device Independent Bitmap (DIB)"
      Case CF_PALETTE
         sFmt = "Palette"
      Case CF_PENDATA
         sFmt = "Pen Data"
      Case CF_RIFF
         sFmt = "RIFF"
      Case CF_WAVE
         sFmt = "Wave"
      Case CF_UNICODETEXT
         sFmt = "Unicode Text"
      Case CF_ENHMETAFILE
         sFmt = "Enhanced Metafile (EMF)"
      Case CF_HDROP
         sFmt = "Dropped Filelist"
      Case CF_LOCALE
         sFmt = "Locale Identifier"
      Case Else
         sFmt = Space(256)
         nRet = GetClipboardFormatName(nFmt, sFmt, Len(sFmt))
         If nRet = 0 Then
            sFmt = "Unknown: " & CStr(nFmt)
         Else
            sFmt = Left$(sFmt, nRet)
         End If
   End Select
   GetName = sFmt
End Function

' ************************************************
'  Friend Methods
' ************************************************
Friend Sub Refresh()
   Dim Fmt As CClipFormat
   Dim nFmt As Long

   ' Reset the collection object
   Set m_Fmts = New Collection

   ' Fill it with each format on the clipboard
   If OpenClipboard(0&) Then
      Do
         Set Fmt = New CClipFormat
         nFmt = EnumClipboardFormats(nFmt)
         If nFmt Then
            Fmt.Format = nFmt
            Fmt.Name = Me.GetName(nFmt)
            m_Fmts.Add Fmt, CStr(nFmt)
         End If
      Loop While nFmt
      Call CloseClipboard
   End If
End Sub



