VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "CClipboard"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Attribute VB_Description = "Global object which replaces the intrinsic with enhanced information and options."
' *************************************************************
'  Copyright 1999, Karl E. Peterson
'  http://www.mvps.org/vb/
' *************************************************************
'  Author grants royalty-free rights to use this code within
'  compiled applications. Selling or otherwise distributing
'  this source code is not allowed without author's express
'  permission.
' *************************************************************
Option Explicit

' Private variables
Private m_Fmts As CClipFormats

' ************************************************
'  Initialization and Termination
' ************************************************
Private Sub Class_Initialize()
   Set m_Fmts = New CClipFormats
End Sub

Private Sub Class_Terminate()
   Set m_Fmts = Nothing
End Sub

' ************************************************
'  Properties
' ************************************************
Public Property Get Formats() As CClipFormats
Attribute Formats.VB_Description = "Returns collection of information about formats present on the system Clipboard."
   ' Expose "New and Improved!" enumeration object.
   m_Fmts.Refresh
   Set Formats = m_Fmts
End Property

Public Property Get Owner() As Long
Attribute Owner.VB_Description = "Returns window handle of Clipboard owner."
   ' Return window handle of Clipboard owner.
   ' Useful(?) if conflicts occur.
   Owner = GetClipboardOwner()
End Property

' ************************************************
'  Public Methods
' ************************************************
Public Function Clear() As Boolean
Attribute Clear.VB_Description = " Clears the contents of a control or the system Clipboard."
   ' Could map directly to the standard object,
   ' but here's the API equivalent.
   If OpenClipboard(0&) Then
      Clear = CBool(EmptyClipboard)
      Call CloseClipboard
   End If
End Function

Public Function GetFormat(ByVal Format As Long) As Boolean
Attribute GetFormat.VB_Description = "Returns a value indicating whether an item on the Clipboard object matches a specified format."
   ' Could map directly to the standard object,
   ' but here's the API equivalent.
   If OpenClipboard(0&) Then
      GetFormat = CBool(IsClipboardFormatAvailable(Format))
      Call CloseClipboard
   End If
End Function

' ************************************************
'  Mapped Public Methods
' ************************************************
Public Function GetData(Optional ByVal Format As Long = vbCFBitmap) As Picture
Attribute GetData.VB_Description = "Returns a graphic from the Clipboard object."
   ' Map directly to intrinsic object.
   On Error Resume Next
   Set GetData = Clipboard.GetData(Format)
End Function

Public Function SetData(ByVal NewVal As Picture, Optional ByVal Format As Long = vbCFBitmap) As Boolean
Attribute SetData.VB_Description = "Puts a picture on the Clipboard object using the specified graphic format."
   ' Map directly to intrinsic object.
   On Error Resume Next
   Clipboard.SetData NewVal, Format
   SetData = (Err.Number = 0)
End Function

Public Function GetText(Optional ByVal Format As Long = vbCFText) As String
Attribute GetText.VB_Description = "Returns a text string from the Clipboard object."
Attribute GetText.VB_UserMemId = 0
   ' Map directly to intrinsic object.
   On Error Resume Next
   GetText = Clipboard.GetText(Format)
End Function

Public Function SetText(ByVal NewVal As String, Optional ByVal Format As Long = vbCFText) As Boolean
Attribute SetText.VB_Description = "Puts a text string on the Clipboard object using the specified Clipboard object format."
   ' Map directly to intrinsic object.
   On Error Resume Next
   Clipboard.SetText NewVal, Format
   SetText = (Err.Number = 0)
End Function



